@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import base64
 
 from mock import patch
@@ -85,8 +86,9 @@ class CompressorTest(TestCase):
         ])
         self.assertMultiLineEqual("""@font-face {
   font-family: 'Pipeline';
-  src: url(http://localhost/static/fonts/pipeline.eot');
-  src: local('☺'), url(http://localhost/static/fonts/pipeline.woff') format('woff'), url(http://localhost/static/fonts/pipeline.ttf') format('truetype'), url(http://localhost/static/fonts/pipeline.svg#IyfZbseF') format('svg');
+  src: url(http://localhost/static/fonts/pipeline.eot);
+  src: url(http://localhost/static/fonts/pipeline.eot?#iefix) format('embedded-opentype');
+  src: local('☺'), url(http://localhost/static/fonts/pipeline.woff) format('woff'), url(http://localhost/static/fonts/pipeline.ttf) format('truetype'), url(http://localhost/static/fonts/pipeline.svg#IyfZbseF) format('svg');
   font-weight: normal;
   font-style: normal;
 }
